@@ -24,6 +24,7 @@ import (
 	"path"
 	"path/filepath"
 	"strings"
+	"syscall"
 	"time"
 
 	"github.com/goplus/gop/ast"
@@ -175,6 +176,9 @@ func (p *Runner) GenGoPkg(pkgDir string, base *cl.Config) (err error) {
 	if err != nil {
 		return p.addError(pkgDir, "parse", err)
 	}
+	if len(pkgs) == 0 {
+		return syscall.ENOENT
+	}
 
 	var pkgTest *ast.Package
 	for name, pkg := range pkgs {
