@@ -18,23 +18,23 @@
 package run
 
 import (
-	"crypto/sha1"
-	"encoding/base64"
 	"fmt"
 	"os"
 	"os/exec"
 	"path/filepath"
 
+	"github.com/qiniu/x/log"
+	"golang.org/x/tools/go/packages"
+
 	"github.com/goplus/gop/ast"
 	"github.com/goplus/gop/cl"
 	"github.com/goplus/gop/cmd/gengo"
 	"github.com/goplus/gop/cmd/internal/base"
+	"github.com/goplus/gop/cmd/internal/modload"
 	"github.com/goplus/gop/parser"
 	"github.com/goplus/gop/scanner"
 	"github.com/goplus/gop/token"
 	"github.com/goplus/gox"
-	"github.com/qiniu/x/log"
-	"golang.org/x/tools/go/packages"
 )
 
 // -----------------------------------------------------------------------------
@@ -74,30 +74,6 @@ func saveGoFile(gofile string, pkg *gox.Package) error {
 	return gox.WriteFile(gofile, pkg, false)
 }
 
-func findGoModFile(dir string) (modfile string, noCacheFile bool, err error) {
-	modfile, err = cl.FindGoModFile(dir)
-	if err != nil {
-		home := os.Getenv("HOME")
-		modfile = home + "/gop/go.mod"
-		if fi, e := os.Lstat(modfile); e == nil && !fi.IsDir() {
-			return modfile, true, nil
-		}
-		modfile = home + "/goplus/go.mod"
-		if fi, e := os.Lstat(modfile); e == nil && !fi.IsDir() {
-			return modfile, true, nil
-		}
-	}
-	return
-}
-
-func findGoModDir(dir string) (string, bool) {
-	modfile, nocachefile, err := findGoModFile(dir)
-	if err != nil {
-		log.Fatalln("findGoModFile:", err)
-	}
-	return filepath.Dir(modfile), nocachefile
-}
-
 func runCmd(cmd *base.Command, args []string) {
 	err := flag.Parse(args)
 	if err != nil {
@@ -135,12 +111,12 @@ func runCmd(cmd *base.Command, args []string) {
 	isDir := fi.IsDir()
 
 	var isDirty bool
-	var srcDir, file, gofile string
+	var srcDir, gofile string
 	var pkgs map[string]*ast.Package
-	onExit = nil
 	if isDir {
 		srcDir = src
 		gofile = src + "/gop_autogen.go"
+		modload.Load()
 		isDirty = true // TODO: check if code changed
 		if isDirty {
 			pkgs, err = parser.ParseDir(fset, src, nil, parserMode)
@@ -148,36 +124,8 @@ func runCmd(cmd *base.Command, args []string) {
 			return
 		}
 	} else {
-		srcDir, file = filepath.Split(src)
-		isGo := filepath.Ext(file) == ".go"
-		if isGo {
-			hash := sha1.Sum([]byte(src))
-			dir := os.Getenv("HOME") + "/.gop/run"
-			os.MkdirAll(dir, 0755)
-			gofile = dir + "/g" + base64.RawURLEncoding.EncodeToString(hash[:]) + file
-			if *flagRTOE { // remove tempfile on error
-				onExit = func() {
-					os.Remove(gofile)
-				}
-			}
-		} else if hasMultiFiles(srcDir, ".gop") {
-			gofile = filepath.Join(srcDir, "gop_autogen_"+file+".go")
-		} else {
-			gofile = srcDir + "/gop_autogen.go"
-		}
-		isDirty = fileIsDirty(fi, gofile)
-		if isDirty {
-			if isGo {
-				fmt.Println("==> GenGo to", gofile)
-			}
-			if *flagGop {
-				pkgs, err = parser.Parse(fset, src, nil, parserMode)
-			} else {
-				pkgs, err = parser.Parse(fset, src, nil, 0) // TODO: only to check dependencies
-			}
-		} else if *flagNorun {
-			return
-		}
+		gopRun(src, args...)
+		return
 	}
 	if err != nil {
 		scanner.PrintError(os.Stderr, err)
@@ -216,18 +164,6 @@ func runCmd(cmd *base.Command, args []string) {
 	}
 }
 
-func fileIsDirty(fi os.FileInfo, gofile string) bool {
-	fiDest, err := os.Stat(gofile)
-	if err != nil {
-		return true
-	}
-	return fi.ModTime().After(fiDest.ModTime())
-}
-
-var (
-	onExit func()
-)
-
 func goRun(file string, args []string) {
 	goArgs := make([]string, len(args)+2)
 	goArgs[0] = "run"
@@ -240,9 +176,6 @@ func goRun(file string, args []string) {
 	cmd.Env = os.Environ()
 	err := cmd.Run()
 	if err != nil {
-		if onExit != nil {
-			onExit()
-		}
 		switch e := err.(type) {
 		case *exec.ExitError:
 			os.Exit(e.ExitCode())
@@ -290,21 +223,4 @@ func runGoPkg(src string, args []string, doRun bool) {
 	}
 }
 
-func hasMultiFiles(srcDir string, ext string) bool {
-	var has bool
-	if f, err := os.Open(srcDir); err == nil {
-		defer f.Close()
-		fis, _ := f.ReadDir(-1)
-		for _, fi := range fis {
-			if !fi.IsDir() && filepath.Ext(fi.Name()) == ext {
-				if has {
-					return true
-				}
-				has = true
-			}
-		}
-	}
-	return false
-}
-
 // -----------------------------------------------------------------------------
